@@ -4,7 +4,7 @@ with_mock_crunch({
     ds <- loadDataset("test ds")
     test_that("Some facts about the fixture dataset", {
         expect_identical(names(ds),
-            c("birthyr", "gender", "mymrset", "textVar", "starttime", "catarray"))
+            c("birthyr", "gender", "location", "mymrset", "textVar", "starttime", "catarray"))
     })
 
     test_that("Basic filter method", {
